@@ -6,7 +6,9 @@ from loguru import logger
 from tortoise import Tortoise, BaseDBAsyncClient, connections
 
 from web_foundation.config import GenericConfig, DbConfig
+from web_foundation.kernel.container import GenericDependencyContainer
 from web_foundation.kernel.messaging.channel import IChannel
+from web_foundation.kernel.stage import ListenerRegistrator, AppStage
 from web_foundation.resources.resource import Resource
 
 
@@ -62,28 +64,32 @@ class DatabaseResource(Resource, Generic[GenericConfig]):
         await Tortoise.init(config=self._get_connection_setting())
         await super(DatabaseResource, self).init(config, channel,
                                                  communicator=Tortoise.get_connection(f'{self._app_name}_default'))
-        await self.configure_db()
 
     async def shutdown(self) -> None:
         await connections.close_all()
+        self.clear()
 
-    async def before_app_run(self, config: GenericConfig, *args, **kwargs):
-        if config.database.with_migrations:
-            await self.init(config)
-            await self.shutdown()
-            config.database.with_migrations = False
-            self._inited = False
+    def set_listeners(self, registrator: ListenerRegistrator, *args, **kwargs):
+        async def before_app_run(stage: AppStage, container: GenericDependencyContainer):
+            if not (config := container.app_config()):
+                raise Exception("Config not in kwargs of set_listeners() ")
+            if config.database.with_migrations:
+                await self.init(config)
+                await self.configure_db()
+                await self.shutdown()
+
+        registrator(AppStage.BEFORE_APP_RUN, before_app_run)
 
     async def _migrations(self, schema_exists: bool, command):
         path_exists = os.path.exists(os.path.join(os.getcwd(), self.db_conf.migrations_path)) and os.listdir(
             os.path.join(os.getcwd(), self.db_conf.migrations_path))
 
         if not path_exists and not schema_exists:
-            await self.create_schema(False)
+            await self._create_schema(False)
             await command.init()
             await command.init_db(safe=True)
         elif not schema_exists:
-            await self.create_schema(False)
+            await self._create_schema(False)
             await command.init()
             await command.upgrade()
         elif not path_exists:
@@ -110,10 +116,10 @@ class DatabaseResource(Resource, Generic[GenericConfig]):
                               location=self.db_conf.migrations_path)
             await self._migrations(schema_exists, command)
         if not schema_exists:
-            await self.create_schema()
+            await self._create_schema()
             await self.fill_db_data()
 
-    async def create_schema(self, generate_schemas: bool = True):
+    async def _create_schema(self, generate_schemas: bool = True):
         await self.communicator.execute_script(f"CREATE SCHEMA IF NOT EXISTS {self.db_conf.db_schema};")
         if generate_schemas:
             await Tortoise.generate_schemas()
