@@ -4,7 +4,7 @@ from typing import Callable, Awaitable, Any
 from typing import List, TypeVar, Tuple, Generic
 
 from pydantic import BaseModel as PdModel
-from tortoise.exceptions import IntegrityError, FieldError
+from tortoise.exceptions import IntegrityError, FieldError, OperationalError
 from tortoise.expressions import RawSQL
 from tortoise.queryset import QuerySet, MODEL
 
@@ -94,7 +94,12 @@ class ModelLoader(Generic[GenericDbType]):
         if kwargs:
             query = query.filter(**kwargs)
         query = await cls.fetch_related(model, query, fetch_fields)
-        entity = await query.first()
+        try:
+            entity = await query.first()
+        except FieldError:
+            raise InconsistencyError(message="Incorrect filter")
+        except OperationalError:
+            raise InconsistencyError(message="Incorrect filter value")
         return entity
 
     @classmethod
@@ -129,6 +134,8 @@ class ModelLoader(Generic[GenericDbType]):
             # ------------------------------------ #
         except FieldError:
             raise InconsistencyError(message="Incorrect filter")
+        except OperationalError:
+            raise InconsistencyError(message="Incorrect filter value")
         return entities, total
 
     @classmethod
